<?php
/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\components;

class DolibarrApi extends AbstractApi
{
    const RESOURCE_INVOICES = 'invoices';
    const RESOURCE_PRODUCTS = 'products';
    const RESOURCE_DOCUMENTS = 'documents';

    public function getInvoicesByThirParty(int $idThirdParty)
    {
        return $this->get(self::RESOURCE_INVOICES, [
            'sortfield' => 't.rowid',
            'sortorder' => 'DESC',
            'thirdparty_ids' => $idThirdParty,
            'limit' => 24
        ]);
    }

    public function getInvoice(int $idInvoice)
    {
        return $this->get(self::RESOURCE_INVOICES.'/'.$idInvoice, [
            'contact_list' => 1
        ]);
    }

    public function downloadInvoice(string $idInvoice)
    {
        $invoice = $this->getInvoice($idInvoice);
        if($invoice && isset($invoice['last_main_doc'])) {
            $originalFilename = str_replace('facture/', '', $invoice['last_main_doc']);

            return $this->get(self::RESOURCE_DOCUMENTS.'/download', [
                'modulepart' => 'facture',
                'original_file' => $originalFilename
            ]);
        }

        return null;
    }

    public function createInvoice(int $idUser)
    {
        return $this->post(self::RESOURCE_INVOICES, [
            'socid' => $idUser,
            'cond_reglement_id' => 2
        ]);
    }

    public function addInvoiceLine(int $idInvoice, int $idProduct)
    {
        $productArray = $this->getProduct($idProduct);

        return $this->post(self::RESOURCE_INVOICES . '/' . $idInvoice . '/lines', [
            'fk_product' => $idProduct,
            'subprice' => $productArray['price'],
            'qty' => 1,
            'desc' => $productArray['description']
        ]);
    }

    public function validateInvoice(int $idInvoice)
    {
        return $this->post(self::RESOURCE_INVOICES . '/' . $idInvoice . '/validate', [], false);
    }

    public function generateInvoicePdf(string $reference)
    {
        return $this->put(self::RESOURCE_DOCUMENTS . '/builddoc', [
            'modulepart' => 'invoice',
            'doctemplate' => 'crabe',
            'langcode' => 'fr_FR',
            'original_file' => $reference.'/'.$reference.'.pdf'
        ]);
    }

    public function getProduct(int $idProduct)
    {
        return $this->get(self::RESOURCE_PRODUCTS . '/' . $idProduct);
    }
}