<?php
/**
Copyright Guillaume Bourgeois (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs
à distribuer leur production en circuits courts.

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant
donné sa spécificité de logiciel libre, qui peut le rendre complexe à
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement,
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
 */

namespace domain\PointSale\PointSale;

use common\helpers\GlobalParam;
use domain\Distribution\Distribution\Distribution;
use domain\_\AbstractService;
use domain\_\SolverInterface;
use yii\helpers\Html;

class PointSaleSolver extends AbstractService implements SolverInterface
{
    public function filterUserPointSalesByDistribution(array $userPointSaleArray, Distribution $distribution): array
    {
        foreach($userPointSaleArray as $key => $userPointSale) {
            if(!$this->isDelivered($userPointSale->pointSale, $distribution)) {
                unset($userPointSaleArray[$key]);
            }
        }

        return $userPointSaleArray;
    }

    public function isDelivered(PointSale $pointSale, Distribution $distribution): bool
    {
        foreach($distribution->pointSaleDistribution as $pointSaleDistribution) {
            if($pointSaleDistribution->pointSale->id == $pointSale->id && $pointSaleDistribution->delivery) {
                return true;
            }
        }

        return false;
    }

    /**
     * Retourne le commentaire de l'utilisateur courant lié au point de vente.
     */
    public function getComment(PointSale $pointSale): ?string
    {
        if (isset($pointSale->userPointSale)) {
            foreach ($pointSale->userPointSale as $userPointSale) {
                if ($userPointSale->id_user == GlobalParam::getCurrentUserId()) {
                    return $userPointSale->comment;
                }
            }
        }

        return null;
    }

    /**
     * Vérifie le code d'accès à un point de vente.
     */
    public function validateCode(PointSale $pointSale, string $code): bool
    {
        if (strlen($pointSale->code)) {
            if (trim(strtolower($code)) == trim(strtolower($pointSale->code))) {
                return true;
            }
            else {
                return false;
            }
        }

        return true;
    }

    /**
     * Retourne les jours de livraison du point de vente sous forme d'une chaine
     * de caractères.
     */
    public function getStrDeliveryDays(PointSale $pointSale): string
    {
        $str = '';

        if ($pointSale->delivery_monday) $str .= 'lundi, ';
        if ($pointSale->delivery_tuesday) $str .= 'mardi, ';
        if ($pointSale->delivery_wednesday) $str .= 'mercredi, ';
        if ($pointSale->delivery_thursday) $str .= 'jeudi, ';
        if ($pointSale->delivery_friday) $str .= 'vendredi, ';
        if ($pointSale->delivery_saturday) $str .= 'samedi, ';
        if ($pointSale->delivery_sunday) $str .= 'dimanche, ';

        if (strlen($str)) {
            return substr($str, 0, strlen($str) - 2);
        } else {
            return '';
        }
    }

    /**
     * Retourne un commentaire informant l'utilisateur sur les détails de
     * livraison d'un point de vente et pour un jour donné.
     */
    public function getStrInfos(PointSale $pointSale, string $day): string
    {
        $str = '';
        $field = 'infos_' . $day;

        if (strlen($pointSale->$field)) {
            $str = nl2br(Html::encode($pointSale->$field));
            $str = preg_replace('/\[select_previous_day\](.*?)\[\/select_previous_day\]/', '<a href="javascript:void(0);" class="select-previous-day">$1</a>', $str);
            $str = preg_replace('@([^>"])(https?://[a-z0-9\./+,%#_-]+)@i', '$1<a href="$2" target="_blank">$2</a>', $str);
        }
        return $str;
    }

    public function getStrInfosByDistribution(PointSale $pointSale, Distribution $distribution): string
    {
        return $this->getStrInfos($pointSale, strtolower(date('l', strtotime($distribution->date))));
    }

    public function getLocalityWithAddressTooltip(PointSale $pointSale): string
    {
        $html = '<span class="locality">';
        if($pointSale->address && strlen($pointSale->address) > 0) {
            $html .= '<span data-bs-toggle="tooltip" data-bs-placement="bottom" title="'.Html::encode($pointSale->address).'">'.Html::encode($pointSale->locality).'</span>';
        }
        else {
            $html .= Html::encode($pointSale->locality);
        }
        $html .= '</span>';

        return $html;
    }

    public function isPublic(PointSale $pointSale): bool
    {
        if($pointSale->restricted_access || ($pointSale->code && strlen($pointSale->code))) {
            return false;
        }

        return true;
    }
}