<?php
/**
Copyright Guillaume Bourgeois (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs
à distribuer leur production en circuits courts.

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant
donné sa spécificité de logiciel libre, qui peut le rendre complexe à
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement,
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
 */

namespace domain\Producer\Producer;

use domain\_\AbstractGenerator;
use domain\PointSale\PointSale\PointSaleRepository;
use domain\Product\Product\ProductRepository;
use yii\helpers\Html;

class ProducerSeoGenerator extends AbstractGenerator
{
    protected ProductRepository $productRepository;
    protected PointSaleRepository $pointSaleRepository;

    public function loadDependencies(): void
    {
        $this->productRepository = $this->loadService(ProductRepository::class);
        $this->pointSaleRepository = $this->loadService(PointSaleRepository::class);
    }

    public function limitMetaDescriptionLength(string $metaDescription): string
    {
        $length = 160;
        if(strlen($metaDescription) > $length) {
            return substr(strip_tags($metaDescription), 0, $length) . ' ...';
        }

        return $metaDescription;
    }

    public function generateMetaDescriptionHome(): string
    {
        $producer = $this->getProducerContext();

        if($producer->description) {
            return $this->limitMetaDescriptionLength($producer->description);
        }
        else {
            $metaDescription = "Bienvenue sur la boutique du producteur ".Html::encode($producer->name);
        }

        return $metaDescription;
    }

    public function generateMetaDescriptionProducts(): string
    {
        $metaDescription = '';
        $productsArray = $this->productRepository->findProducts();

        foreach($productsArray as $product) {
            $metaDescription .= Html::encode($product->name).', ';
        }

        if(strlen($metaDescription)) {
            $metaDescription = substr($metaDescription, 0, strlen($metaDescription) - 2);
        }

        return $this->limitMetaDescriptionLength($metaDescription);
    }

    public function generateMetaDescriptionPointsSale(): string
    {
        $metaDescription = '';
        $pointsSaleArray = $this->pointSaleRepository->findPointSales();

        foreach($pointsSaleArray as $pointSale) {
            $metaDescription .= Html::encode($pointSale->name).', ';
        }

        if(strlen($metaDescription)) {
            $metaDescription = substr($metaDescription, 0, strlen($metaDescription) - 2);
        }

        return $this->limitMetaDescriptionLength($metaDescription);
    }

    public function generateMetaDescriptionOrder(): string
    {
        $producer = $this->getProducerContext();
        return "Passez commande chez ".Html::encode($producer->name)." à la date et au lieu de votre choix.";
    }

    public function generateMetaDescriptionContact(): string
    {
        $producer = $this->getProducerContext();
        return 'Contactez ce producteur en utilisant le formulaire de contact. '
            .Html::encode($producer->name.', '.$producer->address.' '.$producer->postcode.' '.$producer->city);
    }

    public function generateMetaDescriptionSupport()
    {
        return 'Vous rencontrez un problème ? Contactez le développeur du logiciel en utilisant ce formulaire de contact pour poser vos questions ou faire remonter un bug.';
    }
}