<?php
/**
Copyright Guillaume Bourgeois (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs
à distribuer leur production en circuits courts.

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant
donné sa spécificité de logiciel libre, qui peut le rendre complexe à
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement,
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
 */

namespace domain\Setting\SettingDetails;

class AbstractSettingDetail
{
    public string $name;
    public string $label;
    public string $type;
    public string $section;
    public ?string $formType = null;
    public array $options = [];
    public $defaultValue = null;
    public ?string $subSection = null;
    public ?string $helpMessage = null;

    public function setName(string $name): self
    {
        $this->name = $name;
        return $this;
    }

    public function getName(): string
    {
        return $this->name;
    }

    public function setLabel(string $label): self
    {
        $this->label = $label;
        return $this;
    }

    public function getLabel(): string
    {
        return $this->label;
    }

    public function setSection(string $section): self
    {
        $this->section = $section;
        return $this;
    }

    public function getSection(): string
    {
        return $this->section;
    }

    public function setSubSection(string $subSection): self
    {
        $this->subSection = $subSection;
        return $this;
    }

    public function getSubSection(): ?string
    {
        return $this->subSection;
    }

    public function setHelpMessage(string $helpMessage): self
    {
        $this->helpMessage = $helpMessage;
        return $this;
    }

    public function getHelpMessage(): ?string
    {
        return $this->helpMessage;
    }

    public function getFormType(): ?string
    {
        return $this->formType;
    }

    public function setFormTypeInput(): self
    {
        $this->formType = 'input';
        return $this;
    }

    public function setFormTypeTextarea(): self
    {
        $this->formType = 'textarea';
        return $this;
    }

    public function setFormTypeCheckbox(): self
    {
        $this->formType = 'checkbox';
        return $this;
    }

    public function setFormTypeToggle(): self
    {
        $this->formType = 'toggle';
        return $this;
    }

    public function setFormTypeSelect(array $options): self
    {
        $this->formType = 'select';
        $this->options = $options;
        return $this;
    }

    public function getOptions(): array
    {
        return $this->options;
    }

    public function setDefaultValue($defaultValue): self
    {
        $this->defaultValue = $defaultValue;
        return $this;
    }

    public function getDefaultValue()
    {
        return $this->defaultValue;
    }

    public function setTypeString(): self
    {
        $this->type = 'string';
        return $this;
    }

    public function setTypeText(): self
    {
        $this->type = 'text';
        return $this;
    }

    public function setTypeBoolean(): self
    {
        $this->type = 'boolean';
        return $this;
    }

    public function setTypeDate(): self
    {
        $this->type = 'date';
        return $this;
    }

    public function setTypeInteger(): self
    {
        $this->type = 'integer';
        return $this;
    }

    public function setTypeFloat(): self
    {
        $this->type = 'float';
        return $this;
    }

    public function setTypeDouble(): self
    {
        $this->type = 'double';
        return $this;
    }

    public function getType(): string
    {
        return $this->type;
    }
}